=== modified file 'drizzled/field/date.cc'
--- drizzled/field/date.cc	2009-02-11 02:30:38 +0000
+++ drizzled/field/date.cc	2009-02-12 18:16:06 +0000
@@ -18,7 +18,6 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #include "drizzled/server_includes.h"
 #include "drizzled/field/date.h"
 #include "drizzled/error.h"
@@ -26,6 +25,9 @@
 #include "drizzled/temporal.h"
 #include "drizzled/session.h"
 
+#include <sstream>
+#include <string>
+
 #include CMATH_H
 
 #if defined(CMATH_NAMESPACE)
@@ -55,7 +57,6 @@
        nearly-identical class Field_date doesn't ever return 3 from its
        store function.
 */
-
 int Field_date::store(const char *from,
                          uint32_t len,
                          const CHARSET_INFO * const )
@@ -109,53 +110,45 @@
   return 0;
 }
 
-int Field_date::store(double nr)
-{
-  if (nr < 0.0 || nr > 99991231235959.0)
-  {
-    int3store(ptr,(int32_t) 0);
-    set_datetime_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                         ER_WARN_DATA_TRUNCATED, nr, DRIZZLE_TIMESTAMP_DATE);
-    return 1;
-  }
-  return Field_date::store((int64_t) rint(nr), false);
-}
-
-
-int Field_date::store(int64_t nr,
-                         bool )
-{
-  DRIZZLE_TIME l_time;
-  int64_t tmp;
-  int error;
-  Session *session= table ? table->in_use : current_session;
-  if (number_to_datetime(nr, &l_time,
-                         (TIME_FUZZY_DATE |
-                          (session->variables.sql_mode &
-                           (MODE_NO_ZERO_DATE | MODE_INVALID_DATES))),
-                         &error) == INT64_C(-1))
-  {
-    tmp= 0L;
-    error= 2;
-  }
-  else
-    tmp= l_time.day + l_time.month*32 + l_time.year*16*32;
-
-  if (!error && l_time.time_type != DRIZZLE_TIMESTAMP_DATE &&
-      (l_time.hour || l_time.minute || l_time.second || l_time.second_part))
-    error= 3;
-
-  if (error)
-    set_datetime_warning(error == 3 ? DRIZZLE_ERROR::WARN_LEVEL_NOTE :
-                         DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                         error == 2 ?
-                         ER_WARN_DATA_OUT_OF_RANGE : ER_WARN_DATA_TRUNCATED,
-                         nr,DRIZZLE_TIMESTAMP_DATE, 1);
-
-  int3store(ptr,tmp);
-  return error;
-}
-
+int Field_date::store(double from)
+{
+  if (from < 0.0 || from > 99991231235959.0)
+  {
+    /* Convert the double to a string using stringstream */
+    std::stringstream ss;
+    std::string tmp;
+    ss.precision(18); /* 18 places should be fine for error display of double input. */
+    ss << from; ss >> tmp;
+
+    my_error(ER_INVALID_DATETIME_VALUE, MYF(ME_FATALERROR), tmp.c_str());
+    return 2;
+  }
+  return Field_date::store((int64_t) rint(from), false);
+}
+
+int Field_date::store(int64_t from, bool)
+{
+  /* 
+   * Try to create a DateTime from the supplied integer.  Throw an error
+   * if unable to create a valid DateTime.  
+   */
+  drizzled::DateTime temporal;
+  if (! temporal.from_int64_t(from))
+  {
+    /* Convert the integer to a string using stringstream */
+    std::stringstream ss;
+    std::string tmp;
+    ss << from; ss >> tmp;
+
+    my_error(ER_INVALID_DATETIME_VALUE, MYF(ME_FATALERROR), tmp.c_str());
+    return 2;
+  }
+
+  /* Create the stored integer format. @TODO This should go away. Should be up to engine... */
+  uint32_t int_value= (temporal.years() * 16 * 32) + (temporal.months() * 32) + temporal.days();
+  int3store(ptr, int_value);
+  return 0;
+}
 
 int Field_date::store_time(DRIZZLE_TIME *ltime,
                               enum enum_drizzle_timestamp_type time_type)
@@ -199,7 +192,6 @@
   return error;
 }
 
-
 bool Field_date::send_binary(Protocol *protocol)
 {
   DRIZZLE_TIME tm;
@@ -207,13 +199,11 @@
   return protocol->store_date(&tm);
 }
 
-
 double Field_date::val_real(void)
 {
   return (double) Field_date::val_int();
 }
 
-
 int64_t Field_date::val_int(void)
 {
   uint32_t j= uint3korr(ptr);
@@ -221,7 +211,6 @@
   return (int64_t) j;
 }
 
-
 String *Field_date::val_str(String *val_buffer,
 			       String *)
 {
@@ -249,7 +238,6 @@
   return val_buffer;
 }
 
-
 bool Field_date::get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate)
 {
   uint32_t tmp=(uint32_t) uint3korr(ptr);
@@ -262,13 +250,11 @@
           1 : 0);
 }
 
-
 bool Field_date::get_time(DRIZZLE_TIME *ltime)
 {
   return Field_date::get_date(ltime,0);
 }
 
-
 int Field_date::cmp(const unsigned char *a_ptr, const unsigned char *b_ptr)
 {
   uint32_t a,b;
@@ -277,7 +263,6 @@
   return (a < b) ? -1 : (a > b) ? 1 : 0;
 }
 
-
 void Field_date::sort_string(unsigned char *to,uint32_t )
 {
   to[0] = ptr[2];
@@ -285,9 +270,7 @@
   to[2] = ptr[0];
 }
 
-
 void Field_date::sql_type(String &res) const
 {
   res.set_ascii(STRING_WITH_LEN("date"));
 }
-

=== modified file 'drizzled/field/datetime.cc'
--- drizzled/field/datetime.cc	2009-02-11 21:38:28 +0000
+++ drizzled/field/datetime.cc	2009-02-12 18:16:06 +0000
@@ -120,7 +120,7 @@
 int Field_datetime::store(int64_t from, bool)
 {
   /* 
-   * Try to create a DateTime from the supplied string.  Throw an error
+   * Try to create a DateTime from the supplied integer.  Throw an error
    * if unable to create a valid DateTime.  
    */
   drizzled::DateTime temporal;

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2009-02-08 11:11:30 +0000
+++ drizzled/item.cc	2009-02-12 18:16:06 +0000
@@ -297,7 +297,6 @@
 		      collation.collation);
 }
 
-
 Item::Item():
   is_expensive_cache(-1), name(0), orig_name(0), max_length(0), name_length(0),
   unsigned_flag(false), fixed(0), is_autogenerated_name(true),
@@ -325,8 +324,7 @@
   {
     enum_parsing_place place=
       session->lex->current_select->parsing_place;
-    if (place == SELECT_LIST ||
-	place == IN_HAVING)
+    if (place == SELECT_LIST || place == IN_HAVING)
       session->lex->current_select->select_n_having_items++;
   }
 }

=== modified file 'drizzled/item/cmpfunc.cc'
--- drizzled/item/cmpfunc.cc	2009-02-07 22:02:41 +0000
+++ drizzled/item/cmpfunc.cc	2009-02-12 18:16:06 +0000
@@ -21,15 +21,16 @@
   This file defines all compare functions
 */
 
-#include <drizzled/server_includes.h>
-#include <drizzled/sql_select.h>
-#include <drizzled/error.h>
-#include <drizzled/item/cmpfunc.h>
-#include <drizzled/cached_item.h>
-#include <drizzled/item/cache_int.h>
-#include <drizzled/item/int_with_ref.h>
-#include <drizzled/function/bit.h>
-#include <drizzled/check_stack_overrun.h>
+#include "drizzled/server_includes.h"
+#include "drizzled/sql_select.h"
+#include "drizzled/error.h"
+#include "drizzled/temporal.h"
+#include "drizzled/item/cmpfunc.h"
+#include "drizzled/cached_item.h"
+#include "drizzled/item/cache_int.h"
+#include "drizzled/item/int_with_ref.h"
+#include "drizzled/function/bit.h"
+#include "drizzled/check_stack_overrun.h"
 
 #include CMATH_H
 
@@ -730,10 +731,10 @@
          int result and the other item (b or a) is an item with string result.
          If the second item is a constant one then it's checked to be
          convertible to the DATE/DATETIME type. If the constant can't be
-         converted to a DATE/DATETIME then the compare_datetime() comparator
-         isn't used and the warning about wrong DATE/DATETIME value is issued.
+         converted to a DATE/DATETIME then an error is issued back to the Session.
       In all other cases (date-[int|real|decimal]/[int|real|decimal]-date)
       the comparison is handled by other comparators.
+
     If the datetime comparator can be used and one the operands of the
     comparison is a string constant that was successfully converted to a
     DATE/DATETIME type then the result of the conversion is returned in the
@@ -782,19 +783,53 @@
         (str_arg->type() != Item::FUNC_ITEM ||
         ((Item_func*)str_arg)->functype() != Item_func::GUSERVAR_FUNC))
     {
-      Session *session= current_session;
+      /*
+       * OK, we are here if we've got a date field (or something which can be 
+       * compared as a date field) on one side of the equation, and a constant
+       * string on the other side.  In this case, we must verify that the constant
+       * string expression can indeed be evaluated as a datetime.  If it cannot, 
+       * we throw an error here and stop processsing.  Bad data should ALWAYS 
+       * produce an error, and no implicit conversion or truncation should take place.
+       *
+       * If the conversion to a DateTime temporal is successful, then we convert
+       * the Temporal instance to a uint64_t for the comparison operator, which
+       * compares date(times) using int64_t semantics.
+       *
+       * @TODO
+       *
+       * Does a uint64_t conversion really have to happen here?  Fields return int64_t
+       * from val_int(), not uint64_t...
+       */
       uint64_t value;
-      bool error;
-      String tmp, *str_val= 0;
-      enum enum_drizzle_timestamp_type t_type= (date_arg->field_type() == DRIZZLE_TYPE_DATE ?
-                              DRIZZLE_TIMESTAMP_DATE : DRIZZLE_TIMESTAMP_DATETIME);
+      String *str_val;
+      String tmp;
+      /* DateTime used to pick up as many string conversion possibilities as possible. */
+      drizzled::DateTime temporal;
 
       str_val= str_arg->val_str(&tmp);
-      if (str_arg->null_value)
-        return CMP_DATE_DFLT;
-      value= get_date_from_str(session, str_val, t_type, date_arg->name, &error);
-      if (error)
-        return CMP_DATE_DFLT;
+      if (! str_val)
+      {
+        /* 
+         * If we are here, it is most likely due to the comparison item
+         * being a NULL.  Although this is incorrect (SQL demands that the term IS NULL
+         * be used, not = NULL since no item can be equal to NULL).
+         *
+         * So, return gracefully.
+         */
+        return CMP_DATE_DFLT;
+      }
+      if (! temporal.from_string(str_val->c_ptr(), str_val->length()))
+      {
+        /* Chuck an error. Bad datetime input. */
+        my_error(ER_INVALID_DATETIME_VALUE, MYF(ME_FATALERROR), str_val->c_ptr());
+        return CMP_DATE_DFLT; /* :( What else can I return... */
+      }
+
+      /* String conversion was good.  Convert to an integer for comparison purposes. */
+      int64_t int_value;
+      temporal.to_int64_t(&int_value);
+      value= (uint64_t) int_value;
+
       if (const_value)
         *const_value= value;
     }

=== modified file 'drizzled/item/cmpfunc.h'
--- drizzled/item/cmpfunc.h	2009-02-07 22:02:41 +0000
+++ drizzled/item/cmpfunc.h	2009-02-12 18:16:06 +0000
@@ -22,17 +22,15 @@
 
 /* compare and test functions */
 
-#include <drizzled/comp_creator.h>
-#include <drizzled/item/row.h>
-#include <drizzled/item/sum.h>
-#include <drizzled/item/int.h>
-#include <drizzled/item/float.h>
-#include <drizzled/item/decimal.h>
-#include <drizzled/function/math/int.h>
-#include <drizzled/function/numhybrid.h>
-#include <drizzled/session.h>
-
-
+#include "drizzled/comp_creator.h"
+#include "drizzled/item/row.h"
+#include "drizzled/item/sum.h"
+#include "drizzled/item/int.h"
+#include "drizzled/item/float.h"
+#include "drizzled/item/decimal.h"
+#include "drizzled/function/math/int.h"
+#include "drizzled/function/numhybrid.h"
+#include "drizzled/session.h"
 
 extern Item_result item_cmp_type(Item_result a,Item_result b);
 class Item_bool_func2;

=== modified file 'tests/r/loaddata.result'
--- tests/r/loaddata.result	2008-12-16 20:40:18 +0000
+++ tests/r/loaddata.result	2009-02-12 18:16:06 +0000
@@ -169,11 +169,11 @@
 create table t2(f1 int);
 insert into t2 values(1),(2);
 ERROR 01000: Row 1 doesn't contain data for all columns
-select f1 from t1 where f2 <> '0000-00-00 00:00:00' order by f1;
+select f1 from t1 where f2 IS NOT NULL order by f1;
 f1
 delete from t1;
 ERROR 01000: Row 1 doesn't contain data for all columns
-select f1 from t1 where f2 <> '0000-00-00 00:00:00' order by f1;
+select f1 from t1 where f2 IS NOT NULL order by f1;
 f1
 drop table t1,t2;
 CREATE TABLE t1 (c1 INT, c2 TIMESTAMP, c3 REAL, c4 DOUBLE);

=== modified file 'tests/r/select.result'
--- tests/r/select.result	2008-12-06 22:41:03 +0000
+++ tests/r/select.result	2009-02-12 18:16:06 +0000
@@ -1969,10 +1969,7 @@
 CREATE TABLE t2 (  hmid int default NULL,  volid int default NULL,  sampletid int default NULL,  sampletime datetime default NULL,  samplevalue bigint default NULL,  KEY idx1 (hmid,volid,sampletid,sampletime)) ENGINE=MyISAM;
 INSERT INTO t2 VALUES (1,3,10,'2002-06-01 08:00:00',35),(1,3,1010,'2002-06-01 12:00:01',35);
 SELECT a.gvid, (SUM(CASE b.sampletid WHEN 140 THEN b.samplevalue ELSE 0 END)) as the_success,(SUM(CASE b.sampletid WHEN 141 THEN b.samplevalue ELSE 0 END)) as the_fail,(SUM(CASE b.sampletid WHEN 142 THEN b.samplevalue ELSE 0 END)) as the_size,(SUM(CASE b.sampletid WHEN 143 THEN b.samplevalue ELSE 0 END)) as the_time FROM t1 a, t2 b WHERE a.hmid = b.hmid AND a.volid = b.volid AND b.sampletime >= 'wrong-date-value' AND b.sampletime < 'wrong-date-value' AND b.sampletid IN (140, 141, 142, 143) GROUP BY a.gvid;
-gvid	the_success	the_fail	the_size	the_time
-Warnings:
-Warning	1292	Incorrect datetime value: 'wrong-date-value' for column 'sampletime' at row 1
-Warning	1292	Incorrect datetime value: 'wrong-date-value' for column 'sampletime' at row 1
+ERROR HY000: Received an invalid datetime value 'wrong-date-value'.
 SELECT a.gvid, (SUM(CASE b.sampletid WHEN 140 THEN b.samplevalue ELSE 0 END)) as the_success,(SUM(CASE b.sampletid WHEN 141 THEN b.samplevalue ELSE 0 END)) as the_fail,(SUM(CASE b.sampletid WHEN 142 THEN b.samplevalue ELSE 0 END)) as the_size,(SUM(CASE b.sampletid WHEN 143 THEN b.samplevalue ELSE 0 END)) as the_time FROM t1 a, t2 b WHERE a.hmid = b.hmid AND a.volid = b.volid AND b.sampletime >= NULL AND b.sampletime < NULL AND b.sampletid IN (140, 141, 142, 143) GROUP BY a.gvid;
 gvid	the_success	the_fail	the_size	the_time
 DROP TABLE t1,t2;
@@ -2813,45 +2810,17 @@
 insert into t1 values(1,'2005-01-01'),(2,'2005-09-01'),(3,'2005-09-30'),
 (4,'2005-10-01'),(5,'2005-12-30');
 select * from t1 where f2 >= 0            order by f2;
-f1	f2
-1	2005-01-01
-2	2005-09-01
-3	2005-09-30
-4	2005-10-01
-5	2005-12-30
+ERROR HY000: Received an invalid datetime value '0'.
 select * from t1 where f2 >= '0000-00-00' order by f2;
-f1	f2
-1	2005-01-01
-2	2005-09-01
-3	2005-09-30
-4	2005-10-01
-5	2005-12-30
+ERROR HY000: Received an invalid datetime value '0000-00-00'.
 select * from t1 where f2 >= '2005-09-31' order by f2;
-f1	f2
-4	2005-10-01
-5	2005-12-30
-Warnings:
-Warning	1292	Incorrect date value: '2005-09-31' for column 'f2' at row 1
+ERROR HY000: Received an invalid datetime value '2005-09-31'.
 select * from t1 where f2 >= '2005-09-3a' order by f2;
-f1	f2
-3	2005-09-30
-4	2005-10-01
-5	2005-12-30
-Warnings:
-Warning	1292	Incorrect date value: '2005-09-3a' for column 'f2' at row 1
+ERROR HY000: Received an invalid datetime value '2005-09-3a'.
 select * from t1 where f2 <= '2005-09-31' order by f2;
-f1	f2
-1	2005-01-01
-2	2005-09-01
-3	2005-09-30
-Warnings:
-Warning	1292	Incorrect date value: '2005-09-31' for column 'f2' at row 1
+ERROR HY000: Received an invalid datetime value '2005-09-31'.
 select * from t1 where f2 <= '2005-09-3a' order by f2;
-f1	f2
-1	2005-01-01
-2	2005-09-01
-Warnings:
-Warning	1292	Incorrect date value: '2005-09-3a' for column 'f2' at row 1
+ERROR HY000: Received an invalid datetime value '2005-09-3a'.
 drop table t1;
 CREATE TABLE t1(key_a int4 NOT NULL, optimus varchar(32), PRIMARY KEY(key_a));
 CREATE TABLE t2(key_a int4 NOT NULL, prime varchar(32), PRIMARY KEY(key_a));
@@ -3611,129 +3580,6 @@
 1
 1
 DROP TABLE t1, t2, t3;
-select str_to_date('2007-10-09','%Y-%m-%d') between '2007/10/01 00:00:00 GMT'
-                                                and '2007/10/20 00:00:00 GMT';
-str_to_date('2007-10-09','%Y-%m-%d') between '2007/10/01 00:00:00 GMT'
-                                                and '2007/10/20 00:00:00 GMT'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007/10/01 00:00:00 GMT'
-Warning	1292	Truncated incorrect datetime value: '2007/10/20 00:00:00 GMT'
-select str_to_date('2007-10-09','%Y-%m-%d') > '2007/10/01 00:00:00 GMT-6';
-str_to_date('2007-10-09','%Y-%m-%d') > '2007/10/01 00:00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect date value: '2007/10/01 00:00:00 GMT-6'
-select str_to_date('2007-10-09','%Y-%m-%d') <= '2007/10/2000:00:00 GMT-6';
-str_to_date('2007-10-09','%Y-%m-%d') <= '2007/10/2000:00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect date value: '2007/10/2000:00:00 GMT-6'
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-1 00:00:00 GMT-6';
-str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-1 00:00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect date value: '2007-10-1 00:00:00 GMT-6'
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 x00:00:00 GMT-6';
-str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 x00:00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect date value: '2007-10-01 x00:00:00 GMT-6'
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:00:00 GMT-6';
-str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 00:00:00 GMT-6'
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:x00:00 GMT-6';
-str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:x00:00 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 00:x00:00 GMT-6'
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 x12:34:56 GMT-6';
-str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 x12:34:56 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 x12:34:56 GMT-6'
-select str_to_date('2007-10-01 12:34:00','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
-str_to_date('2007-10-01 12:34:00','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 12:34x:56 GMT-6'
-select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
-str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6'
-0
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 12:34x:56 GMT-6'
-select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34:56';
-str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34:56'
-1
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 12:00:00';
-str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 12:00:00'
-0
-select str_to_date('2007-10-01 12','%Y-%m-%d %H') = '2007-10-01 12:00:00';
-str_to_date('2007-10-01 12','%Y-%m-%d %H') = '2007-10-01 12:00:00'
-1
-select str_to_date('2007-10-01 12:34','%Y-%m-%d %H') = '2007-10-01 12:00:00';
-str_to_date('2007-10-01 12:34','%Y-%m-%d %H') = '2007-10-01 12:00:00'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-10-01 12:34'
-select str_to_date('2007-02-30 12:34','%Y-%m-%d %H:%i') = '2007-02-30 12:34';
-str_to_date('2007-02-30 12:34','%Y-%m-%d %H:%i') = '2007-02-30 12:34'
-0
-Warnings:
-Warning	1292	Truncated incorrect datetime value: '2007-02-30 12:34'
-select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '2007-10-00 12:34';
-str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '2007-10-00 12:34'
-1
-select str_to_date('2007-10-00','%Y-%m-%d') between '2007/09/01 00:00:00'
-                                                and '2007/10/20 00:00:00';
-str_to_date('2007-10-00','%Y-%m-%d') between '2007/09/01 00:00:00'
-                                                and '2007/10/20 00:00:00'
-1
-select str_to_date('2007-10-00','%Y-%m-%d') between '' and '2007/10/20';
-str_to_date('2007-10-00','%Y-%m-%d') between '' and '2007/10/20'
-1
-Warnings:
-Warning	1292	Truncated incorrect datetime value: ''
-select str_to_date('','%Y-%m-%d') between '2007/10/01' and '2007/10/20';
-str_to_date('','%Y-%m-%d') between '2007/10/01' and '2007/10/20'
-0
-select str_to_date('','%Y-%m-%d %H:%i') = '2007-10-01 12:34';
-str_to_date('','%Y-%m-%d %H:%i') = '2007-10-01 12:34'
-0
-select str_to_date(NULL,'%Y-%m-%d %H:%i') = '2007-10-01 12:34';
-str_to_date(NULL,'%Y-%m-%d %H:%i') = '2007-10-01 12:34'
-NULL
-select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '';
-str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = ''
-0
-Warnings:
-Warning	1292	Truncated incorrect datetime value: ''
-select str_to_date('1','%Y-%m-%d') = '1';
-str_to_date('1','%Y-%m-%d') = '1'
-0
-Warnings:
-Warning	1292	Truncated incorrect date value: '1'
-select str_to_date('1','%Y-%m-%d') = '1';
-str_to_date('1','%Y-%m-%d') = '1'
-0
-Warnings:
-Warning	1292	Truncated incorrect date value: '1'
-select str_to_date('','%Y-%m-%d') = '';
-str_to_date('','%Y-%m-%d') = ''
-0
-Warnings:
-Warning	1292	Truncated incorrect date value: ''
-select str_to_date('1000-01-01','%Y-%m-%d') between '0000-00-00' and NULL;
-str_to_date('1000-01-01','%Y-%m-%d') between '0000-00-00' and NULL
-0
-select str_to_date('1000-01-01','%Y-%m-%d') between NULL and '2000-00-00';
-str_to_date('1000-01-01','%Y-%m-%d') between NULL and '2000-00-00'
-0
-select str_to_date('1000-01-01','%Y-%m-%d') between NULL and NULL;
-str_to_date('1000-01-01','%Y-%m-%d') between NULL and NULL
-0
 
 #
 # Bug#30736: Row Size Too Large Error Creating a Table and

=== modified file 'tests/r/type_date.result'
--- tests/r/type_date.result	2009-02-11 02:30:38 +0000
+++ tests/r/type_date.result	2009-02-12 18:16:06 +0000
@@ -121,7 +121,7 @@
 ERROR HY000: Received an invalid datetime value '1311'.
 create table t1 (d  date , dt datetime , ts timestamp);
 insert into t1 values (9912101,9912101,9912101);
-ERROR 22007: Incorrect date value: '9912101' for column 'd' at row 1
+ERROR HY000: Received an invalid datetime value '9912101'.
 insert into t1 values (11111,11111,11111);
 select * from t1;
 d	dt	ts

=== modified file 'tests/r/type_ranges.result'
--- tests/r/type_ranges.result	2009-02-11 21:38:28 +0000
+++ tests/r/type_ranges.result	2009-02-12 18:16:06 +0000
@@ -84,7 +84,7 @@
 CREATE INDEX test2 on t1 ( ulonglong,ulong) ;
 CREATE INDEX test3 on t1 ( medium ) ;
 DROP INDEX test ON t1;
-insert into t1 values (10, 1,1,1,1,1,1,1,1,1,1,1,1,1,NULL,0,0,NULL,1,1,1,1,'one','one');
+insert into t1 values (10, 1,1,1,1,1,1,1,1,1,1,1,1,1,NULL,NULL,0,NULL,1,1,1,1,'one','one');
 insert into t1 values (NULL,2,2,2,2,2,2,2,2,2,2,2,2,2,NULL,NULL,NULL,NULL,NULL,NULL,2,2,'two','one');
 insert into t1 values (0,1/3,3,3,3,3,3,3,3,3,3,3,3,3,NULL,'19970303','10:10:10','19970303101010','','','','3',3,3);
 ERROR 22001: Data too long for column 'string' at row 1
@@ -97,7 +97,7 @@
 insert into t1 (tiny) values (1);
 select auto,string,tiny,short,medium,long_int,longlong,real_float,real_double,utiny,ushort,umedium,ulong,ulonglong,mod(floor(time_stamp/1000000),1000000)-mod(curdate(),1000000),date_field,time_field,date_time,blob_col,tinyblob_col,mediumblob_col,longblob_col from t1;
 auto	string	tiny	short	medium	long_int	longlong	real_float	real_double	utiny	ushort	umedium	ulong	ulonglong	mod(floor(time_stamp/1000000),1000000)-mod(curdate(),1000000)	date_field	time_field	date_time	blob_col	tinyblob_col	mediumblob_col	longblob_col
-10	1	1	1	1	1	1	1	1	1	1	1	1	1	0	0000-00-00	00:00:00	NULL	1	1	1	1
+10	1	1	1	1	1	1	1	1	1	1	1	1	1	0	NULL	00:00:00	NULL	1	1	1	1
 11	2	2	2	2	2	2	2	2	2	2	2	2	2	0	NULL	NULL	NULL	NULL	NULL	2	2
 12	hello	1	1	0	0	0	0	NULL	0	0	0	0	0	0	NULL	NULL	NULL	NULL	NULL		
 CREATE TABLE t2 (

=== modified file 'tests/t/loaddata.test'
--- tests/t/loaddata.test	2008-12-16 20:40:18 +0000
+++ tests/t/loaddata.test	2009-02-12 18:16:06 +0000
@@ -154,7 +154,7 @@
 --error 1261
 eval load data infile '$MYSQLTEST_VARDIR/tmp/t2' into table t1;
 enable_query_log;
-select f1 from t1 where f2 <> '0000-00-00 00:00:00' order by f1;
+select f1 from t1 where f2 IS NOT NULL order by f1;
 remove_file $MYSQLTEST_VARDIR/tmp/t2;
 delete from t1;
 disable_query_log;
@@ -165,7 +165,7 @@
 eval load data infile '$MYSQLTEST_VARDIR/tmp/t2' into table t1
 FIELDS TERMINATED BY '' OPTIONALLY ENCLOSED BY '' LINES TERMINATED BY '\r\n';
 enable_query_log;
-select f1 from t1 where f2 <> '0000-00-00 00:00:00' order by f1;
+select f1 from t1 where f2 IS NOT NULL order by f1;
 remove_file $MYSQLTEST_VARDIR/tmp/t2;
 drop table t1,t2;
 

=== modified file 'tests/t/select.test'
--- tests/t/select.test	2008-12-06 22:41:03 +0000
+++ tests/t/select.test	2009-02-12 18:16:06 +0000
@@ -1792,10 +1792,8 @@
 INSERT INTO t1 VALUES (200001,2,1,1,100,1,1,1,0,0,0,1,0,1,20020425060057,'\\\\ARKIVIO-TESTPDC\\E$',''),(200002,2,2,1,101,1,1,1,0,0,0,1,0,1,20020425060057,'\\\\ARKIVIO-TESTPDC\\C$',''),(200003,1,3,2,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1,0,1,20020425060427,'c:',NULL);
 CREATE TABLE t2 (  hmid int default NULL,  volid int default NULL,  sampletid int default NULL,  sampletime datetime default NULL,  samplevalue bigint default NULL,  KEY idx1 (hmid,volid,sampletid,sampletime)) ENGINE=MyISAM;
 INSERT INTO t2 VALUES (1,3,10,'2002-06-01 08:00:00',35),(1,3,1010,'2002-06-01 12:00:01',35);
-# Disable PS becasue we get more warnings from PS than from normal execution
---disable_ps_protocol
+--error 1686 # bad datetime
 SELECT a.gvid, (SUM(CASE b.sampletid WHEN 140 THEN b.samplevalue ELSE 0 END)) as the_success,(SUM(CASE b.sampletid WHEN 141 THEN b.samplevalue ELSE 0 END)) as the_fail,(SUM(CASE b.sampletid WHEN 142 THEN b.samplevalue ELSE 0 END)) as the_size,(SUM(CASE b.sampletid WHEN 143 THEN b.samplevalue ELSE 0 END)) as the_time FROM t1 a, t2 b WHERE a.hmid = b.hmid AND a.volid = b.volid AND b.sampletime >= 'wrong-date-value' AND b.sampletime < 'wrong-date-value' AND b.sampletid IN (140, 141, 142, 143) GROUP BY a.gvid;
---enable_ps_protocol
 # Testing the same select with NULL's instead of invalid datetime values
 SELECT a.gvid, (SUM(CASE b.sampletid WHEN 140 THEN b.samplevalue ELSE 0 END)) as the_success,(SUM(CASE b.sampletid WHEN 141 THEN b.samplevalue ELSE 0 END)) as the_fail,(SUM(CASE b.sampletid WHEN 142 THEN b.samplevalue ELSE 0 END)) as the_size,(SUM(CASE b.sampletid WHEN 143 THEN b.samplevalue ELSE 0 END)) as the_time FROM t1 a, t2 b WHERE a.hmid = b.hmid AND a.volid = b.volid AND b.sampletime >= NULL AND b.sampletime < NULL AND b.sampletid IN (140, 141, 142, 143) GROUP BY a.gvid;
 DROP TABLE t1,t2;
@@ -2587,13 +2585,18 @@
 insert into t1 values(1,'2005-01-01'),(2,'2005-09-01'),(3,'2005-09-30'),
   (4,'2005-10-01'),(5,'2005-12-30');
 # should return all records
+--error 1686 # Bad date
 select * from t1 where f2 >= 0            order by f2;
+--error 1686 # Bad date
 select * from t1 where f2 >= '0000-00-00' order by f2;
 # should return 4,5
+--error 1686 # Bad date
 select * from t1 where f2 >= '2005-09-31' order by f2;
+--error 1686 # Bad date
 select * from t1 where f2 >= '2005-09-3a' order by f2;
-# should return 1,2,3
+--error 1686 # Bad date
 select * from t1 where f2 <= '2005-09-31' order by f2;
+--error 1686 # Bad date
 select * from t1 where f2 <= '2005-09-3a' order by f2;
 drop table t1;
 
@@ -3296,58 +3299,60 @@
 # Bug#31800: Date comparison fails with timezone and slashes for greater
 #            than comparison
 #
-
+#
+# @TODO Commenting all str_to_date out for now...should move to a plugin.
+#
 # On DATETIME-like literals with trailing garbage, BETWEEN fudged in a
 # DATETIME comparator, while greater/less-than used bin-string comparisons.
 # Should correctly be compared as DATE or DATETIME, but throw a warning:
 
-select str_to_date('2007-10-09','%Y-%m-%d') between '2007/10/01 00:00:00 GMT'
-                                                and '2007/10/20 00:00:00 GMT';
-select str_to_date('2007-10-09','%Y-%m-%d') > '2007/10/01 00:00:00 GMT-6';
-select str_to_date('2007-10-09','%Y-%m-%d') <= '2007/10/2000:00:00 GMT-6';
+#select str_to_date('2007-10-09','%Y-%m-%d') between '2007/10/01 00:00:00 GMT'
+#                                                and '2007/10/20 00:00:00 GMT';
+#select str_to_date('2007-10-09','%Y-%m-%d') > '2007/10/01 00:00:00 GMT-6';
+#select str_to_date('2007-10-09','%Y-%m-%d') <= '2007/10/2000:00:00 GMT-6';
 
 # We have all we need -- and trailing garbage:
 # (leaving out a leading zero in first example to prove it's a
 # value-comparison, not a string-comparison!)
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-1 00:00:00 GMT-6';
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 x00:00:00 GMT-6';
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:00:00 GMT-6';
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:x00:00 GMT-6';
+#select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-1 00:00:00 GMT-6';
+#select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 x00:00:00 GMT-6';
+#select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:00:00 GMT-6';
+#select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 00:x00:00 GMT-6';
 # no time at all:
-select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 x12:34:56 GMT-6';
+#select str_to_date('2007-10-01','%Y-%m-%d %H:%i:%s') = '2007-10-01 x12:34:56 GMT-6';
 # partial time:
-select str_to_date('2007-10-01 12:34:00','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
+#select str_to_date('2007-10-01 12:34:00','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
 # fail, different second part:
-select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
+#select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34x:56 GMT-6';
 # correct syntax, no trailing nonsense -- this one must throw no warning:
-select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34:56';
+#select str_to_date('2007-10-01 12:34:56','%Y-%m-%d %H:%i:%s') = '2007-10-01 12:34:56';
 # no warning, but failure (different hour parts):
-select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 12:00:00';
+#select str_to_date('2007-10-01','%Y-%m-%d') = '2007-10-01 12:00:00';
 # succeed:
-select str_to_date('2007-10-01 12','%Y-%m-%d %H') = '2007-10-01 12:00:00';
+#select str_to_date('2007-10-01 12','%Y-%m-%d %H') = '2007-10-01 12:00:00';
 # succeed, but warn for "trailing garbage" (":34"):
-select str_to_date('2007-10-01 12:34','%Y-%m-%d %H') = '2007-10-01 12:00:00';
+#select str_to_date('2007-10-01 12:34','%Y-%m-%d %H') = '2007-10-01 12:00:00';
 # invalid date (Feb 30) succeeds
-select str_to_date('2007-02-30 12:34','%Y-%m-%d %H:%i') = '2007-02-30 12:34';
+#select str_to_date('2007-02-30 12:34','%Y-%m-%d %H:%i') = '2007-02-30 12:34';
 # 0-day for both, just works in default SQL mode.
-select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '2007-10-00 12:34';
+#select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '2007-10-00 12:34';
 # 0-day, succeed
-select str_to_date('2007-10-00','%Y-%m-%d') between '2007/09/01 00:00:00'
-                                                and '2007/10/20 00:00:00';
-select str_to_date('2007-10-00','%Y-%m-%d') between '' and '2007/10/20';
-select str_to_date('','%Y-%m-%d') between '2007/10/01' and '2007/10/20';
-select str_to_date('','%Y-%m-%d %H:%i') = '2007-10-01 12:34';
-select str_to_date(NULL,'%Y-%m-%d %H:%i') = '2007-10-01 12:34';
-select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '';
+#select str_to_date('2007-10-00','%Y-%m-%d') between '2007/09/01 00:00:00'
+#                                                and '2007/10/20 00:00:00';
+#select str_to_date('2007-10-00','%Y-%m-%d') between '' and '2007/10/20';
+#select str_to_date('','%Y-%m-%d') between '2007/10/01' and '2007/10/20';
+#select str_to_date('','%Y-%m-%d %H:%i') = '2007-10-01 12:34';
+#select str_to_date(NULL,'%Y-%m-%d %H:%i') = '2007-10-01 12:34';
+#select str_to_date('2007-10-00 12:34','%Y-%m-%d %H:%i') = '';
 
-select str_to_date('1','%Y-%m-%d') = '1';
-select str_to_date('1','%Y-%m-%d') = '1';
-select str_to_date('','%Y-%m-%d') = '';
+#select str_to_date('1','%Y-%m-%d') = '1';
+#select str_to_date('1','%Y-%m-%d') = '1';
+#select str_to_date('','%Y-%m-%d') = '';
 
 # these three should work!
-select str_to_date('1000-01-01','%Y-%m-%d') between '0000-00-00' and NULL;
-select str_to_date('1000-01-01','%Y-%m-%d') between NULL and '2000-00-00';
-select str_to_date('1000-01-01','%Y-%m-%d') between NULL and NULL;
+#select str_to_date('1000-01-01','%Y-%m-%d') between '0000-00-00' and NULL;
+#select str_to_date('1000-01-01','%Y-%m-%d') between NULL and '2000-00-00';
+#select str_to_date('1000-01-01','%Y-%m-%d') between NULL and NULL;
 ###########################################################################
 
 --echo

=== modified file 'tests/t/type_date.test'
--- tests/t/type_date.test	2009-02-11 02:30:38 +0000
+++ tests/t/type_date.test	2009-02-12 18:16:06 +0000
@@ -129,7 +129,7 @@
 --error 1686 # Invalid datetime of 1311
 select year(@d), month(@d), day(@d), cast(@d as date);
 create table t1 (d  date , dt datetime , ts timestamp);
--- error 1292
+-- error 1686 # Bad dates
 insert into t1 values (9912101,9912101,9912101);
 insert into t1 values (11111,11111,11111);
 select * from t1;

=== modified file 'tests/t/type_ranges.test'
--- tests/t/type_ranges.test	2009-02-11 21:38:28 +0000
+++ tests/t/type_ranges.test	2009-02-12 18:16:06 +0000
@@ -56,7 +56,7 @@
 CREATE INDEX test3 on t1 ( medium ) ;
 DROP INDEX test ON t1;
 
-insert into t1 values (10, 1,1,1,1,1,1,1,1,1,1,1,1,1,NULL,0,0,NULL,1,1,1,1,'one','one');
+insert into t1 values (10, 1,1,1,1,1,1,1,1,1,1,1,1,1,NULL,NULL,0,NULL,1,1,1,1,'one','one');
 insert into t1 values (NULL,2,2,2,2,2,2,2,2,2,2,2,2,2,NULL,NULL,NULL,NULL,NULL,NULL,2,2,'two','one');
 --error 1406
 insert into t1 values (0,1/3,3,3,3,3,3,3,3,3,3,3,3,3,NULL,'19970303','10:10:10','19970303101010','','','','3',3,3);

